-- import pour MySQL
-- 2019-10-02T17:24:12+02:00 RFS

CREATE TABLE Assiste
  (
    idSeance INTEGER NOT NULL ,
    idGroupe INTEGER NOT NULL
  );

ALTER TABLE Assiste ADD CONSTRAINT Assiste_PK PRIMARY KEY (idGroupe, idSeance) ;

CREATE TABLE Batiment
  (
    idBatiment INTEGER NOT NULL ,
    Intitule   VARCHAR2 (45) ,
    nbEtages   INTEGER NOT NULL
  ) ;
ALTER TABLE Batiment ADD CONSTRAINT Batiment_PK PRIMARY KEY ( idBatiment ) ;


CREATE TABLE Cours
  (
    idCours     INTEGER NOT NULL ,
    Intitule    VARCHAR2 (45) NOT NULL ,
    Responsable INTEGER NOT NULL ,
    Niveau      CHAR (2) NOT NULL ,
    nbHeuresMax INTEGER NOT NULL ,
    Coeff       INTEGER NOT NULL
  ) ;
ALTER TABLE Cours ADD CHECK ( Niveau IN ('L1', 'L2', 'L3', 'M1', 'M2')) ;
CREATE INDEX fk_Enseignement_Enseignant_idx ON Cours
  ( Responsable ASC
  ) ;
ALTER TABLE Cours ADD CONSTRAINT Cours_PKv2 PRIMARY KEY ( idCours ) ;


CREATE TABLE Enseignant
  (
    idEnseignant INTEGER NOT NULL ,
    Nom          VARCHAR2 (45) ,
    Prenom       VARCHAR2 (45) ,
    status       VARCHAR2 (10) NOT NULL
  ) ;
ALTER TABLE Enseignant ADD CHECK ( status IN ('Moniteur', 'Titulaire', 'Vacataire')) ;
ALTER TABLE Enseignant ADD CONSTRAINT Enseignant_PK PRIMARY KEY ( idEnseignant ) ;


CREATE TABLE Etudiant
  (
    idEtudiant INTEGER NOT NULL ,
    Nom        VARCHAR2 (45) NOT NULL ,
    Prenom     VARCHAR2 (45) NOT NULL ,
    dateNaiss  DATE NOT NULL
  ) ;
ALTER TABLE Etudiant ADD CONSTRAINT Etudiant_PK PRIMARY KEY ( idEtudiant ) ;


CREATE TABLE Groupe
  (
    idGroupe  INTEGER NOT NULL ,
    NumGroupe INTEGER NOT NULL
  ) ;
ALTER TABLE Groupe ADD CONSTRAINT Groupe_PK PRIMARY KEY ( idGroupe ) ;


CREATE TABLE Inscription
  (
    idParcours INTEGER NOT NULL ,
    idEtudiant INTEGER NOT NULL ,
    annee      INTEGER NOT NULL ,
    moyenne    NUMBER (3,1) ,
    mention    VARCHAR2 (2)
  ) ;
ALTER TABLE Inscription ADD CHECK ( mention IN ('AB', 'B', 'E', 'P', 'TB')) ;
CREATE INDEX fk_Inscription_Etudiant1_idx ON Inscription
  ( idEtudiant ASC
  ) ;
ALTER TABLE Inscription ADD CONSTRAINT Inscription_PK PRIMARY KEY ( idParcours, idEtudiant, annee ) ;


CREATE TABLE Parcours
  (
    idParcours INTEGER NOT NULL ,
    Intitule   VARCHAR2 (45) NOT NULL ,
    Niveau     CHAR (2) NOT NULL
  ) ;
ALTER TABLE Parcours ADD CHECK ( Niveau IN ('L1', 'L2', 'L3', 'M1', 'M2')) ;
ALTER TABLE Parcours ADD CONSTRAINT Parcours_PK PRIMARY KEY ( idParcours ) ;


CREATE TABLE Participe
  (
    idGroupe   INTEGER NOT NULL ,
    idEtudiant INTEGER NOT NULL
  )
  ;
ALTER TABLE Participe ADD CONSTRAINT Participe_PK PRIMARY KEY ( idEtudiant, idGroupe ) ;


CREATE TABLE Passage
  (
    idParcours    INTEGER NOT NULL ,
    idParcoursSup INTEGER NOT NULL
  ) ;
CREATE INDEX fk_Passage_Parcours2_idx ON Passage
  ( idParcoursSup ASC
  ) ;
ALTER TABLE Passage ADD CONSTRAINT Passage_PK PRIMARY KEY ( idParcours, idParcoursSup ) ;


CREATE TABLE Resultat
  (
    idEtudiant INTEGER NOT NULL ,
    idCours    INTEGER NOT NULL ,
    annee      INTEGER NOT NULL ,
    Note       NUMBER (3,1)
  ) ;
CREATE INDEX fk_Resultat_Cours_idx ON Resultat
  ( idCours ASC
  ) ;
ALTER TABLE Resultat ADD CONSTRAINT Resultat_PK PRIMARY KEY ( idEtudiant, idCours, annee ) ;


CREATE TABLE Salle
  (
    idSalle    INTEGER NOT NULL ,
    idBatiment INTEGER ,
    Etage      INTEGER NOT NULL ,
    Num        INTEGER NOT NULL ,
    Capacite   INTEGER ,
    type       VARCHAR2 (5)
  ) ;
ALTER TABLE Salle ADD CHECK ( type IN ('Amphi', 'TD', 'TP')) ;
CREATE INDEX fk_Salle_Batiment1_idx ON Salle
  ( idBatiment ASC
  ) ;
ALTER TABLE Salle ADD CONSTRAINT Salle_PK PRIMARY KEY ( idSalle ) ;


CREATE TABLE Seance
  (
    idSeance     INTEGER NOT NULL ,
    idCours      INTEGER NOT NULL ,
    DateHeureDeb DATE NOT NULL ,
    duree        INTEGER NOT NULL ,
    idSalle      INTEGER NOT NULL ,
    idEnseignant INTEGER NOT NULL ,
    type         VARCHAR2 (5) NOT NULL
  ) ;
ALTER TABLE Seance ADD CHECK ( type IN ('Cours', 'TD', 'TP')) ;
CREATE INDEX fk_Cours_Salle1_idx ON Seance
  ( idSalle ASC
  ) ;
CREATE INDEX fk_Cours_Enseignant1_idx ON Seance
  ( idEnseignant ASC
  ) ;
ALTER TABLE Seance ADD CONSTRAINT Seance_PK PRIMARY KEY ( idSeance ) ;


CREATE TABLE Service
  (
    idEnseignant  INTEGER NOT NULL ,
    annee         INTEGER NOT NULL ,
    nbHeuresCours INTEGER ,
    nbHeuresTD    INTEGER ,
    nbHeuresTP    INTEGER
  ) ;
ALTER TABLE Service ADD CONSTRAINT Service_PK PRIMARY KEY ( idEnseignant, annee ) ;

CREATE TABLE CompositionCours
  (
    idParcours INTEGER NOT NULL ,
    idCours    INTEGER NOT NULL
  ) ;
ALTER TABLE CompositionCours ADD CONSTRAINT CompositionCours_PK PRIMARY KEY ( idParcours, idCours ) ;


ALTER TABLE Assiste ADD CONSTRAINT Assiste_Groupe_FK FOREIGN KEY ( idGroupe ) REFERENCES Groupe ( idGroupe ) ON DELETE CASCADE;

ALTER TABLE Assiste ADD CONSTRAINT Assiste_Seance_FK FOREIGN KEY ( idSeance ) REFERENCES Seance ( idSeance );

ALTER TABLE Seance ADD CONSTRAINT fk_Cours_Enseignant1 FOREIGN KEY ( idEnseignant ) REFERENCES Enseignant ( idEnseignant );

ALTER TABLE Seance ADD CONSTRAINT fk_Cours_Enseignement1 FOREIGN KEY ( idCours ) REFERENCES Cours ( idCours );

ALTER TABLE Seance ADD CONSTRAINT fk_Cours_Salle1 FOREIGN KEY ( idSalle ) REFERENCES Salle ( idSalle );

ALTER TABLE Cours ADD CONSTRAINT fk_Enseignement_Enseignant1 FOREIGN KEY ( Responsable ) REFERENCES Enseignant ( idEnseignant ) ;

ALTER TABLE Inscription ADD CONSTRAINT fk_Inscription_Etudiant1 FOREIGN KEY ( idEtudiant ) REFERENCES Etudiant ( idEtudiant ) ;

ALTER TABLE Inscription ADD CONSTRAINT fk_Inscription_Parcours1 FOREIGN KEY ( idParcours ) REFERENCES Parcours ( idParcours );

ALTER TABLE Passage ADD CONSTRAINT fk_Passage_Parcours1 FOREIGN KEY ( idParcours ) REFERENCES Parcours ( idParcours );

ALTER TABLE Passage ADD CONSTRAINT fk_Passage_Parcours2 FOREIGN KEY ( idParcoursSup ) REFERENCES Parcours ( idParcours );

ALTER TABLE Resultat ADD CONSTRAINT fk_Resultat_Cours FOREIGN KEY ( idCours ) REFERENCES Cours ( idCours ) ;
ALTER TABLE Resultat ADD CONSTRAINT fk_Resultat_Etudiant FOREIGN KEY ( idEtudiant ) REFERENCES Etudiant ( idEtudiant ) ;

ALTER TABLE Salle ADD CONSTRAINT fk_Salle_Batiment1 FOREIGN KEY ( idBatiment ) REFERENCES Batiment ( idBatiment );

ALTER TABLE Service ADD CONSTRAINT fk_Service_Enseignant FOREIGN KEY ( idEnseignant ) REFERENCES Enseignant ( idEnseignant );

ALTER TABLE CompositionCours ADD CONSTRAINT CompositionCours_Cours_FK FOREIGN KEY ( idCours ) REFERENCES Cours ( idCours ) ;
ALTER TABLE CompositionCours ADD CONSTRAINT CompositionCours_Parcours_FK FOREIGN KEY ( idParcours ) REFERENCES Parcours ( idParcours ) ;

--

INSERT INTO Batiment (idBatiment,Intitule,nbEtages) VALUES (1,'Batiment A',2);
INSERT INTO Batiment (idBatiment,Intitule,nbEtages) VALUES (2,'Batiment B',3);
INSERT INTO Batiment (idBatiment,Intitule,nbEtages) VALUES (3,'Batiment C',2);

INSERT INTO Salle (idSalle,idBatiment,Etage,Num,Capacite,type) VALUES (1,1,1,110,30,'TD');
INSERT INTO Salle (idSalle,idBatiment,Etage,Num,Capacite,type) VALUES (2,1,0,5,100,'Amphi');
INSERT INTO Salle (idSalle,idBatiment,Etage,Num,Capacite,type) VALUES (3,2,2,5,200,'Amphi');
INSERT INTO Salle (idSalle,idBatiment,Etage,Num,Capacite,type) VALUES (4,2,0,7,30,'TD');
INSERT INTO Salle (idSalle,idBatiment,Etage,Num,Capacite,type) VALUES (5,3,2,4,20,'TP');
INSERT INTO Salle (idSalle,idBatiment,Etage,Num,Capacite,type) VALUES (6,2,3,20,20,'TP');

INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (1,'Dupont','Kevin',STR_TO_DATE('1992-10-01', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (2,'Durand','Andre',STR_TO_DATE('1992-05-02', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (3,'Lopez','Philippe',STR_TO_DATE('1989-09-25', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (4,'Poquelin','Jean-Baptiste',STR_TO_DATE('1985-05-12', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (5,'Jaquemin','Olivier',STR_TO_DATE('1992-11-05', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (6,'Olivera','Magalie',STR_TO_DATE('1992-07-03', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (7,'Tayachi','Aouatef',STR_TO_DATE('1990-03-20', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (8,'Guillard','Caroline',STR_TO_DATE('1991-06-15', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (9,'Achard','Carine',STR_TO_DATE('1990-02-10', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (10, 'Hmedeh','Taieb',STR_TO_DATE('1993-01-05', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (11,'Nguyen','Wu',STR_TO_DATE('1992-12-12', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (12,'Kon vi','Miyoung',STR_TO_DATE('1991-10-19', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (13,'Long','Darrel',STR_TO_DATE('1990-05-16', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (14,'Echasse','Bertrand',STR_TO_DATE('1992-07-06', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (15,'Naullau','Roger',STR_TO_DATE('1992-09-05', '%Y-%m-%d'));
INSERT INTO Etudiant (idEtudiant,Nom,Prenom,dateNaiss) VALUES (16,'Ramirez','Vincent',STR_TO_DATE('1992-03-03', '%Y-%m-%d'));

INSERT INTO Parcours (idParcours,Intitule,Niveau) VALUES (1,'Informatique','M1');
INSERT INTO Parcours (idParcours,Intitule,Niveau) VALUES (2,'Informatique - OSY','M2');
INSERT INTO Parcours (idParcours,Intitule,Niveau) VALUES (3,'ITB','M2');

INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,1,2014,NULL,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,2,2013,9.0,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,2,2014,NULL,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,3,2014,NULL,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,4,2012,14.0,'TB');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,5,2013,16.0,'TB');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,6,2013,15.0,'B');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,7,2011,18.0,'E');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,8,2012,16.0,'TB');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,9,2011,14.0,'B');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,10,2014,NULL,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,11,2013,15.0,'B');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,12,2012,13.0,'AB');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,13,2011,12.0,'AB');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,14,2014,NULL,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,15,2014,NULL,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (1,16,2014,NULL,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (2,5,2014,0.0,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (2,6,2014,NULL,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (2,8,2013,15.0,'B');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (2,11,2014,NULL,NULL);
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (2,12,2013,14.0,'B');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (3,4,2013,13.0,'B');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (3,7,2012,17.0,'TB');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (3,9,2012,16.0,'TB');
INSERT INTO Inscription (idParcours,idEtudiant,annee,moyenne,mention) VALUES (3,13,2012,12.0,'AB');

INSERT INTO Enseignant (idEnseignant,Nom,Prenom,status) VALUES (1,'Travers','Nicolas','Vacataire');
INSERT INTO Enseignant (idEnseignant,Nom,Prenom,status) VALUES (2,'Mourier','Pascale','Titulaire');
INSERT INTO Enseignant (idEnseignant,Nom,Prenom,status) VALUES (3,'Boisson','Francois','Vacataire');
INSERT INTO Enseignant (idEnseignant,Nom,Prenom,status) VALUES (4,'Mathieu','Eric','Titulaire');
INSERT INTO Enseignant (idEnseignant,Nom,Prenom,status) VALUES (5,'Chu','Chengbin','Titulaire');
INSERT INTO Enseignant (idEnseignant,Nom,Prenom,status) VALUES (6,'Boutin','Philippe','Titulaire');
INSERT INTO Enseignant (idEnseignant,Nom,Prenom,status) VALUES (7,'Escribe','Julien','Vacataire');
INSERT INTO Enseignant (idEnseignant,Nom,Prenom,status) VALUES (8,'Znaty','David','Vacataire');
INSERT INTO Enseignant (idEnseignant,Nom,Prenom,status) VALUES (9,'Abal-Kassim','Cheik Ahamed','Vacataire');

INSERT INTO Service (idEnseignant,annee,nbHeuresCours,nbHeuresTD,nbHeuresTP) VALUES (1,2013,20,10,6);
INSERT INTO Service (idEnseignant,annee,nbHeuresCours,nbHeuresTD,nbHeuresTP) VALUES (1,2014,40,10,12);
INSERT INTO Service (idEnseignant,annee,nbHeuresCours,nbHeuresTD,nbHeuresTP) VALUES (2,2013,30,30,20);
INSERT INTO Service (idEnseignant,annee,nbHeuresCours,nbHeuresTD,nbHeuresTP) VALUES (2,2014,20,30,10);
INSERT INTO Service (idEnseignant,annee,nbHeuresCours,nbHeuresTD,nbHeuresTP) VALUES (3,2014,0,15,10);
INSERT INTO Service (idEnseignant,annee,nbHeuresCours,nbHeuresTD,nbHeuresTP) VALUES (4,2013,50,0,0);
INSERT INTO Service (idEnseignant,annee,nbHeuresCours,nbHeuresTD,nbHeuresTP) VALUES (5,2014,45,0,0);

INSERT INTO Cours (idCours,Intitule,Responsable,Niveau,nbHeuresMax,Coeff) VALUES (1,'Introduction aux Bases de Donnees',1,'M1',30,3);
INSERT INTO Cours (idCours,Intitule,Responsable,Niveau,nbHeuresMax,Coeff) VALUES (2,'Immeubles de Grandes Hauteurs',4,'M1',30,2);
INSERT INTO Cours (idCours,Intitule,Responsable,Niveau,nbHeuresMax,Coeff) VALUES (3,'Production et distribution de biens et de ser',5,'M1',30,2);
INSERT INTO Cours (idCours,Intitule,Responsable,Niveau,nbHeuresMax,Coeff) VALUES (4,'Bases de Donnees Avancees',1,'M2',30,5);
INSERT INTO Cours (idCours,Intitule,Responsable,Niveau,nbHeuresMax,Coeff) VALUES (5,'Architecture des Systemes Materiel',6,'M2',8,1);
INSERT INTO Cours (idCours,Intitule,Responsable,Niveau,nbHeuresMax,Coeff) VALUES (6,'IT Business / Introduction',7,'M2',20,3);
INSERT INTO Cours (idCours,Intitule,Responsable,Niveau,nbHeuresMax,Coeff) VALUES (7,'IT Business / Strategie et Management',8,'M2',10,1);

INSERT INTO CompositionCours (idParcours,idCours) VALUES (1,1);
INSERT INTO CompositionCours (idParcours,idCours) VALUES (1,2);
INSERT INTO CompositionCours (idParcours,idCours) VALUES (1,3);
INSERT INTO CompositionCours (idParcours,idCours) VALUES (2,4);
INSERT INTO CompositionCours (idParcours,idCours) VALUES (3,4);
INSERT INTO CompositionCours (idParcours,idCours) VALUES (2,5);
INSERT INTO CompositionCours (idParcours,idCours) VALUES (2,6);
INSERT INTO CompositionCours (idParcours,idCours) VALUES (3,6);
INSERT INTO CompositionCours (idParcours,idCours) VALUES (2,7);
INSERT INTO CompositionCours (idParcours,idCours) VALUES (3,7);

INSERT INTO Groupe (idGroupe, numGroupe) VALUES (1,1);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (2,2);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (3,1);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (4,2);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (5,1);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (6,2);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (7,1);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (8,2);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (9,3);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (10, 1);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (11,2);
INSERT INTO Groupe (idGroupe, numGroupe) VALUES (12,3);

INSERT INTO Participe (idGroupe,idEtudiant) VALUES (6,1);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (5,2);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (6,2);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (6,3);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (1,4);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (5,5);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (5,6);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (3,7);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (4,8);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (3,9);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (12,10);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (5,11);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (1,12);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (3,13);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (12,14);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (12,15);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (12,16);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (8,5);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (8,6);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (7,8);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (9,11);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (7,12);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (11,4);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (10, 7);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (10, 9);
INSERT INTO Participe (idGroupe,idEtudiant) VALUES (10, 13);

INSERT INTO Seance (idSeance, idCours, DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (1,1,STR_TO_DATE('2012-09-15 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (1, 1);
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (1, 3);
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (1, 4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (2,1,STR_TO_DATE('2012-09-15 10:45:00', '%Y-%m-%d %H:%i:%s'),90,2,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (2, 1);
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (2, 3);
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (2, 4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (3,1,STR_TO_DATE('2012-09-16 13:00:00', '%Y-%m-%d %H:%i:%s'),90,1,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (3, 1);
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (3, 3);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (4,1,STR_TO_DATE('2012-09-16 14:45:00', '%Y-%m-%d %H:%i:%s'),90,1,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (4, 1);
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (4, 3);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (5,1,STR_TO_DATE('2012-09-16 13:00:00', '%Y-%m-%d %H:%i:%s'),90,4,2,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (5, 4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (6,1,STR_TO_DATE('2012-09-16 14:45:00', '%Y-%m-%d %H:%i:%s'),90,4,2,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (6, 4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (7,1,STR_TO_DATE('2013-09-15 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (7, 5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (8,1,STR_TO_DATE('2014-09-15 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (8, 6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (9,1,STR_TO_DATE('2013-09-15 10:45:00', '%Y-%m-%d %H:%i:%s'),90,3,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (9, 5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (10,1,STR_TO_DATE('2013-09-16 13:00:00', '%Y-%m-%d %H:%i:%s'),90,4,3,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (10, 5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (11,1,STR_TO_DATE('2013-09-16 14:45:00', '%Y-%m-%d %H:%i:%s'),90,4,3,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (11, 5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (12,1,STR_TO_DATE('2014-09-15 10:45:00', '%Y-%m-%d %H:%i:%s'),90,1,3,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (12, 6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (13,1,STR_TO_DATE('2014-09-16 10:00:00', '%Y-%m-%d %H:%i:%s'),90,2,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (13, 6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (14,1,STR_TO_DATE('2014-09-16 13:00:00', '%Y-%m-%d %H:%i:%s'),90,1,3,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (14, 6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (15,1,STR_TO_DATE('2014-09-15 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (15, 12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (16,1,STR_TO_DATE('2014-09-15 10:45:00', '%Y-%m-%d %H:%i:%s'),90,6,3,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (16, 12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (17,1,STR_TO_DATE('2014-09-16 10:00:00', '%Y-%m-%d %H:%i:%s'),90,2,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (17, 12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (18,1,STR_TO_DATE('2014-09-16 13:00:00', '%Y-%m-%d %H:%i:%s'),90,4,3,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (18, 12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (19,2,STR_TO_DATE('2012-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (19, 1);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (20,2,STR_TO_DATE('2012-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,2,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (20, 1);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (21,2,STR_TO_DATE('2012-09-17 09:00:00', '%Y-%m-%d %H:%i:%s'),90,1,4,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (21,  1);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (22,2,STR_TO_DATE('2012-09-17 13:00:00', '%Y-%m-%d %H:%i:%s'),90,1,4,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (22,  1);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (23,2,STR_TO_DATE('2011-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (23,  3);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (24,2,STR_TO_DATE('2011-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,2,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (24,  3);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (25,2,STR_TO_DATE('2011-09-17 10:00:00', '%Y-%m-%d %H:%i:%s'),90,1,4,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (25,  3);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (26,2,STR_TO_DATE('2011-09-17 13:00:00', '%Y-%m-%d %H:%i:%s'),90,1,4,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (26,  3);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (27,2,STR_TO_DATE('2012-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (27,  4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (28,2,STR_TO_DATE('2012-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,2,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (28,  4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (29,2,STR_TO_DATE('2012-09-17 09:00:00', '%Y-%m-%d %H:%i:%s'),90,4,3,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (29,  4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (30,2,STR_TO_DATE('2012-09-17 13:00:00', '%Y-%m-%d %H:%i:%s'),90,5,3,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (30,  4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (31,2,STR_TO_DATE('2013-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (31,  5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (32,2,STR_TO_DATE('2013-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,3,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (32,   5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (33,2,STR_TO_DATE('2013-09-17 10:00:00', '%Y-%m-%d %H:%i:%s'),90,4,4,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (33,   5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (34,2,STR_TO_DATE('2013-09-17 13:00:00', '%Y-%m-%d %H:%i:%s'),90,4,4,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (34,   5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (35,2,STR_TO_DATE('2014-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (35,   6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (36,2,STR_TO_DATE('2014-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,1,4,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (36,   6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (37,2,STR_TO_DATE('2014-09-16 14:45:00', '%Y-%m-%d %H:%i:%s'),90,1,4,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (37,   6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (38,2,STR_TO_DATE('2014-09-16 16:30:00', '%Y-%m-%d %H:%i:%s'),90,2,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (38,   6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (39,2,STR_TO_DATE('2014-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (39,   12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (40,2,STR_TO_DATE('2014-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,4,4,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (40, 12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (41,2,STR_TO_DATE('2014-09-16 14:45:00', '%Y-%m-%d %H:%i:%s'),90,4,4,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (41,  12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (42,2,STR_TO_DATE('2014-09-16 16:30:00', '%Y-%m-%d %H:%i:%s'),90,2,4,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (42,  12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (43,3,STR_TO_DATE('2012-09-16 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (43,  1);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (44,3,STR_TO_DATE('2012-09-16 10:45:00', '%Y-%m-%d %H:%i:%s'),90,2,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (44,  1);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (45,3,STR_TO_DATE('2012-09-16 16:30:00', '%Y-%m-%d %H:%i:%s'),90,1,5,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (45,  1);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (46,3,STR_TO_DATE('2012-09-17 14:45:00', '%Y-%m-%d %H:%i:%s'),90,1,5,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (46,  1);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (47,3,STR_TO_DATE('2011-09-16 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (47,  3);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (48,3,STR_TO_DATE('2011-09-16 10:45:00', '%Y-%m-%d %H:%i:%s'),90,2,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (48,  3);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (49,3,STR_TO_DATE('2011-09-16 16:30:00', '%Y-%m-%d %H:%i:%s'),90,1,5,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (49,  3);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (50,3,STR_TO_DATE('2011-09-17 14:45:00', '%Y-%m-%d %H:%i:%s'),90,1,5,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (50, 3);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (51,3,STR_TO_DATE('2012-09-16 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (51, 4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (52,3,STR_TO_DATE('2012-09-16 10:45:00', '%Y-%m-%d %H:%i:%s'),90,2,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (52, 4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (53,3,STR_TO_DATE('2012-09-16 16:30:00', '%Y-%m-%d %H:%i:%s'),90,4,3,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (53, 4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (54,3,STR_TO_DATE('2012-09-17 14:45:00', '%Y-%m-%d %H:%i:%s'),90,4,3,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (54, 4);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (55,3,STR_TO_DATE('2013-09-16 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (55, 5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (56,3,STR_TO_DATE('2013-09-16 10:45:00', '%Y-%m-%d %H:%i:%s'),90,3,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (56, 5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (57,3,STR_TO_DATE('2013-09-16 16:30:00', '%Y-%m-%d %H:%i:%s'),90,4,5,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (57, 5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (58,3,STR_TO_DATE('2013-09-17 14:45:00', '%Y-%m-%d %H:%i:%s'),90,4,5,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (58, 5);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (59,3,STR_TO_DATE('2014-09-17 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (59, 6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (60,3,STR_TO_DATE('2014-09-17 10:45:00', '%Y-%m-%d %H:%i:%s'),90,1,5,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (60, 6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (61,3,STR_TO_DATE('2014-09-17 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (61, 6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (62,3,STR_TO_DATE('2014-09-17 14:45:00', '%Y-%m-%d %H:%i:%s'),90,1,5,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (62, 6);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (63,3,STR_TO_DATE('2014-09-17 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (63, 12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (64,3,STR_TO_DATE('2014-09-17 10:45:00', '%Y-%m-%d %H:%i:%s'),90,4,5,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (64, 12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (65,3,STR_TO_DATE('2014-09-17 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,5,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (65, 12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (66,3,STR_TO_DATE('2014-09-17 14:45:00', '%Y-%m-%d %H:%i:%s'),90,4,5,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (66, 12);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (67,4,STR_TO_DATE('2013-09-15 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (67, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (68,4,STR_TO_DATE('2013-09-15 10:45:00', '%Y-%m-%d %H:%i:%s'),90,1,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (68, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (69,4,STR_TO_DATE('2013-09-16 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (69, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (70,4,STR_TO_DATE('2013-09-16 10:45:00', '%Y-%m-%d %H:%i:%s'),90,1,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (70, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (71,4,STR_TO_DATE('2014-09-15 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (71, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (72,4,STR_TO_DATE('2014-09-15 10:45:00', '%Y-%m-%d %H:%i:%s'),90,5,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (72, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (73,4,STR_TO_DATE('2014-09-16 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (73, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (74,4,STR_TO_DATE('2014-09-16 10:45:00', '%Y-%m-%d %H:%i:%s'),90,1,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (74, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (75,4,STR_TO_DATE('2014-09-15 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (75, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (76,4,STR_TO_DATE('2014-09-15 10:45:00', '%Y-%m-%d %H:%i:%s'),90,4,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (76, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (77,4,STR_TO_DATE('2014-09-16 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (77, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (78,4,STR_TO_DATE('2014-09-16 10:45:00', '%Y-%m-%d %H:%i:%s'),90,4,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (78, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (79,4,STR_TO_DATE('2012-09-15 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (79, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (80,4,STR_TO_DATE('2012-09-15 10:45:00', '%Y-%m-%d %H:%i:%s'),90,4,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (80, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (81,4,STR_TO_DATE('2012-09-16 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (81, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (82,4,STR_TO_DATE('2012-09-16 10:45:00', '%Y-%m-%d %H:%i:%s'),90,1,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (82, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (83,4,STR_TO_DATE('2013-09-15 09:00:00', '%Y-%m-%d %H:%i:%s'),90,1,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (83, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (84,4,STR_TO_DATE('2013-09-15 10:45:00', '%Y-%m-%d %H:%i:%s'),90,4,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (84, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (85,4,STR_TO_DATE('2013-09-16 09:00:00', '%Y-%m-%d %H:%i:%s'),90,1,1,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (85, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (86,4,STR_TO_DATE('2013-09-16 10:45:00', '%Y-%m-%d %H:%i:%s'),90,5,1,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (86, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (87,5,STR_TO_DATE('2013-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,6,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (87, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (88,5,STR_TO_DATE('2013-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,5,6,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (88, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (89,5,STR_TO_DATE('2013-09-16 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,6,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (89, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (90,5,STR_TO_DATE('2013-09-16 14:45:00', '%Y-%m-%d %H:%i:%s'),90,5,6,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (90, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (91,5,STR_TO_DATE('2014-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,6,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (91, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (92,5,STR_TO_DATE('2014-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,6,6,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (92, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (93,5,STR_TO_DATE('2014-09-16 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,6,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (93, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (94,5,STR_TO_DATE('2014-09-16 14:45:00', '%Y-%m-%d %H:%i:%s'),90,6,6,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (94, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (95,5,STR_TO_DATE('2014-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,6,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (95, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (96,5,STR_TO_DATE('2014-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,5,6,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (96, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (97,5,STR_TO_DATE('2014-09-16 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,6,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (97, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (98,5,STR_TO_DATE('2014-09-16 14:45:00', '%Y-%m-%d %H:%i:%s'),90,5,6,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (98, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (99,6,STR_TO_DATE('2013-09-17 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,7,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (99, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (100,6,STR_TO_DATE('2013-09-17 10:45:00', '%Y-%m-%d %H:%i:%s'),90,5,7,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (100, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (101,6,STR_TO_DATE('2013-09-18 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,8,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (101, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (102,6,STR_TO_DATE('2013-09-18 14:45:00', '%Y-%m-%d %H:%i:%s'),90,6,8,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (102, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (103,6,STR_TO_DATE('2014-09-17 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,7,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (103, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (104,6,STR_TO_DATE('2014-09-17 10:45:00', '%Y-%m-%d %H:%i:%s'),90,5,7,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (104, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (105,6,STR_TO_DATE('2014-09-18 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,7,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (105, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (106,6,STR_TO_DATE('2014-09-18 14:45:00', '%Y-%m-%d %H:%i:%s'),90,1,7,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (106, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (107,6,STR_TO_DATE('2014-09-17 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,7,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (107, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (108,6,STR_TO_DATE('2014-09-17 10:45:00', '%Y-%m-%d %H:%i:%s'),90,6,7,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (108, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (109,6,STR_TO_DATE('2014-09-18 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,7,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (109, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (110,6,STR_TO_DATE('2014-09-18 14:45:00', '%Y-%m-%d %H:%i:%s'),90,4,7,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (110, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (111,6,STR_TO_DATE('2012-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,7,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (111, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (112,6,STR_TO_DATE('2012-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,5,7,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (112, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (113,6,STR_TO_DATE('2012-09-16 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,7,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (113, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (114,6,STR_TO_DATE('2012-09-16 14:45:00', '%Y-%m-%d %H:%i:%s'),90,5,7,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (114, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (115,6,STR_TO_DATE('2013-09-15 13:00:00', '%Y-%m-%d %H:%i:%s'),90,1,7,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (115, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (116,6,STR_TO_DATE('2013-09-15 14:45:00', '%Y-%m-%d %H:%i:%s'),90,6,7,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (116, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (117,6,STR_TO_DATE('2013-09-16 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,7,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (117, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (118,6,STR_TO_DATE('2013-09-16 14:45:00', '%Y-%m-%d %H:%i:%s'),90,6,7,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (118, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (119,7,STR_TO_DATE('2013-09-17 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,8,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (119, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (120,7,STR_TO_DATE('2013-09-17 14:45:00', '%Y-%m-%d %H:%i:%s'),90,6,8,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (120, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (121,7,STR_TO_DATE('2013-09-18 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,7,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (121, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (122,7,STR_TO_DATE('2013-09-18 10:45:00', '%Y-%m-%d %H:%i:%s'),90,5,7,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (122, 7);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (123,7,STR_TO_DATE('2014-09-17 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,8,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (123, 8);
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (123, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (124,7,STR_TO_DATE('2014-09-17 14:45:00', '%Y-%m-%d %H:%i:%s'),90,6,8,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (124, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (125,7,STR_TO_DATE('2014-09-18 10:45:00', '%Y-%m-%d %H:%i:%s'),90,6,8,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (125, 8);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (126,7,STR_TO_DATE('2014-09-18 13:00:00', '%Y-%m-%d %H:%i:%s'),90,3,8,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (126, 8);
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (126, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (128,7,STR_TO_DATE('2014-09-17 14:45:00', '%Y-%m-%d %H:%i:%s'),90,5,8,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (128, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (129,7,STR_TO_DATE('2014-09-18 10:45:00', '%Y-%m-%d %H:%i:%s'),90,5,8,'TP');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (129, 9);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (131,7,STR_TO_DATE('2012-09-17 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,8,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (131, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (132,7,STR_TO_DATE('2012-09-17 10:45:00', '%Y-%m-%d %H:%i:%s'),90,4,8,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (132, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (133,7,STR_TO_DATE('2012-09-17 13:00:00', '%Y-%m-%d %H:%i:%s'),90,2,8,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (133, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (134,7,STR_TO_DATE('2012-09-17 14:45:00', '%Y-%m-%d %H:%i:%s'),90,5,8,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (134, 10);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (135,7,STR_TO_DATE('2013-09-17 09:00:00', '%Y-%m-%d %H:%i:%s'),90,2,8,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (135, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (136,7,STR_TO_DATE('2013-09-17 10:45:00', '%Y-%m-%d %H:%i:%s'),90,1,8,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (136, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (137,7,STR_TO_DATE('2013-09-18 09:00:00', '%Y-%m-%d %H:%i:%s'),90,3,8,'Cours');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (137, 11);
INSERT INTO Seance (idSeance,idCours,DateHeureDeb,duree,idSalle,idEnseignant,type) VALUES (138,7,STR_TO_DATE('2013-09-18 10:45:00', '%Y-%m-%d %H:%i:%s'),90,1,8,'TD');
INSERT INTO Assiste (IdSeance, IdGroupe) VALUES (138, 11);

INSERT INTO Passage (idParcours,idParcoursSup) VALUES (1,2);
INSERT INTO Passage (idParcours,idParcoursSup) VALUES (1,3);

INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (2,1,2013,7.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (2,2,2013,10.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (2,3,2013,11.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (4,1,2012,16.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (4,2,2012,13.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (4,3,2012,12.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (4,4,2013,14.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (4,6,2013,12.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (4,7,2013,11.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (5,1,2013,15.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (5,2,2013,16.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (5,3,2013,17.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (6,1,2013,17.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (6,2,2013,13.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (6,3,2013,14.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (7,1,2011,18.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (7,2,2011,17.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (7,3,2011,19.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (7,4,2012,17.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (7,6,2012,16.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (7,7,2012,16.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (8,1,2012,16.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (8,2,2012,16.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (8,3,2012,15.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (8,4,2013,14.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (8,5,2013,15.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (8,6,2013,16.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (8,7,2013,15.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (9,1,2011,13.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (9,2,2011,15.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (9,3,2011,14.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (9,4,2012,15.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (9,6,2012,16.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (9,7,2012,18.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (11,1,2013,15.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (11,2,2013,15.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (11,3,2013,14.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (12,1,2012,14.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (12,2,2012,10.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (12,3,2012,14.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (12,4,2013,14.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (12,5,2013,15.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (12,6,2013,13.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (12,7,2013,16.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (13,1,2011,12.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (13,2,2011,12.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (13,3,2011,12.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (13,4,2012,10.0);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (13,6,2012,15.5);
INSERT INTO Resultat (idEtudiant,idCours,annee,Note) VALUES (13,7,2012,11.5);
