-- Gnr par Oracle SQL Developer Data Modeler 4.1.1.888
--    :        2015-09-15 00:03:40 CEST
--   site :      Oracle Database 12c
--   type :      Oracle Database 12c




CREATE TABLE Assiste
  (
    idSeance INTEGER NOT NULL ,
    idGroupe INTEGER NOT NULL
  )
ALTER TABLE Assiste ADD CONSTRAINT Assiste_PK PRIMARY KEY ( idGroupe, idSeance ) ;


CREATE TABLE Batiment
  (
    idBatiment INTEGER NOT NULL ,
    Intitule   VARCHAR2 (45) ,
    nbEtages   INTEGER NOT NULL
  ) ;
ALTER TABLE Batiment ADD CONSTRAINT Batiment_PK PRIMARY KEY ( idBatiment ) ;


CREATE TABLE Cours
  (
    idCours     INTEGER NOT NULL ,
    Intitule    VARCHAR2 (45) NOT NULL ,
    Responsable INTEGER NOT NULL ,
    Niveau      CHAR (2) NOT NULL ,
    nbHeuresMax INTEGER NOT NULL ,
    Coeff       INTEGER NOT NULL
  ) ;
ALTER TABLE Cours ADD CHECK ( Niveau IN ('L1', 'L2', 'L3', 'M1', 'M2')) ;
CREATE INDEX fk_Enseignement_Enseignant_idx ON Cours
  ( Responsable ASC
  ) ;
ALTER TABLE Cours ADD CONSTRAINT Cours_PKv2 PRIMARY KEY ( idCours ) ;


CREATE TABLE Enseignant
  (
    idEnseignant INTEGER NOT NULL ,
    Nom          VARCHAR2 (45) ,
    Prenom       VARCHAR2 (45) ,
    status       VARCHAR2 (10) NOT NULL
  ) ;
ALTER TABLE Enseignant ADD CHECK ( status IN ('Moniteur', 'Titulaire', 'Vacataire')) ;
ALTER TABLE Enseignant ADD CONSTRAINT Enseignant_PK PRIMARY KEY ( idEnseignant ) ;


CREATE TABLE Etudiant
  (
    idEtudiant INTEGER NOT NULL ,
    Nom        VARCHAR2 (45) NOT NULL ,
    Prenom     VARCHAR2 (45) NOT NULL ,
    dateNaiss  DATE NOT NULL
  ) ;
ALTER TABLE Etudiant ADD CONSTRAINT Etudiant_PK PRIMARY KEY ( idEtudiant ) ;


CREATE TABLE Groupe
  (
    idGroupe  INTEGER NOT NULL ,
    NumGroupe INTEGER NOT NULL
  ) ;
ALTER TABLE Groupe ADD CONSTRAINT Groupe_PK PRIMARY KEY ( idGroupe ) ;


CREATE TABLE Inscription
  (
    idParcours INTEGER NOT NULL ,
    idEtudiant INTEGER NOT NULL ,
    annee      INTEGER NOT NULL ,
    moyenne    NUMBER (3,1) ,
    mention    VARCHAR2 (2)
  ) ;
ALTER TABLE Inscription ADD CHECK ( mention IN ('AB', 'B', 'E', 'P', 'TB')) ;
CREATE INDEX fk_Inscription_Etudiant1_idx ON Inscription
  ( idEtudiant ASC
  ) ;
ALTER TABLE Inscription ADD CONSTRAINT Inscription_PK PRIMARY KEY ( idParcours, idEtudiant, annee ) ;


CREATE TABLE Parcours
  (
    idParcours INTEGER NOT NULL ,
    Intitule   VARCHAR2 (45) NOT NULL ,
    Niveau     CHAR (2) NOT NULL
  ) ;
ALTER TABLE Parcours ADD CHECK ( Niveau IN ('L1', 'L2', 'L3', 'M1', 'M2')) ;
ALTER TABLE Parcours ADD CONSTRAINT Parcours_PK PRIMARY KEY ( idParcours ) ;


CREATE TABLE Participe
  (
    idGroupe   INTEGER NOT NULL ,
    idEtudiant INTEGER NOT NULL
  ) ;
ALTER TABLE Participe ADD CONSTRAINT Participe_PK PRIMARY KEY ( idEtudiant, idGroupe ) ;


CREATE TABLE Passage
  (
    idParcours    INTEGER NOT NULL ,
    idParcoursSup INTEGER NOT NULL
  ) ;
CREATE INDEX fk_Passage_Parcours2_idx ON Passage
  ( idParcoursSup ASC
  ) ;
ALTER TABLE Passage ADD CONSTRAINT Passage_PK PRIMARY KEY ( idParcours, idParcoursSup ) ;


CREATE TABLE Resultat
  (
    idEtudiant INTEGER NOT NULL ,
    idCours    INTEGER NOT NULL ,
    annee      INTEGER NOT NULL ,
    Note       NUMBER (3,1)
  ) ;
CREATE INDEX fk_Resultat_Cours_idx ON Resultat
  ( idCours ASC
  ) ;
ALTER TABLE Resultat ADD CONSTRAINT Resultat_PK PRIMARY KEY ( idEtudiant, idCours, annee ) ;


CREATE TABLE Salle
  (
    idSalle    INTEGER NOT NULL ,
    idBatiment INTEGER ,
    Etage      INTEGER NOT NULL ,
    Num        INTEGER NOT NULL ,
    Capacite   INTEGER ,
    type       VARCHAR2 (5)
  ) ;
ALTER TABLE Salle ADD CHECK ( type IN ('Amphi', 'TD', 'TP')) ;
CREATE INDEX fk_Salle_Batiment1_idx ON Salle
  ( idBatiment ASC
  ) ;
ALTER TABLE Salle ADD CONSTRAINT Salle_PK PRIMARY KEY ( idSalle ) ;


CREATE TABLE Seance
  (
    idSeance     INTEGER NOT NULL ,
    idCours      INTEGER NOT NULL ,
    DateHeureDeb DATE NOT NULL ,
    duree        INTEGER NOT NULL ,
    idSalle      INTEGER NOT NULL ,
    idEnseignant INTEGER NOT NULL ,
    type         VARCHAR2 (5) NOT NULL
  ) ;
ALTER TABLE Seance ADD CHECK ( type IN ('Cours', 'TD', 'TP')) ;
CREATE INDEX fk_Cours_Salle1_idx ON Seance
  ( idSalle ASC
  ) ;
CREATE INDEX fk_Cours_Enseignant1_idx ON Seance
  ( idEnseignant ASC
  ) ;
ALTER TABLE Seance ADD CONSTRAINT Seance_PK PRIMARY KEY ( idSeance ) ;


CREATE TABLE Service
  (
    idEnseignant  INTEGER NOT NULL ,
    annee         INTEGER NOT NULL ,
    nbHeuresCours INTEGER ,
    nbHeuresTD    INTEGER ,
    nbHeuresTP    INTEGER
  ) ;
ALTER TABLE Service ADD CONSTRAINT Service_PK PRIMARY KEY ( idEnseignant, annee ) ;

CREATE TABLE CompositionCours
  (
    idParcours INTEGER NOT NULL ,
    idCours    INTEGER NOT NULL
  ) ;
ALTER TABLE CompositionCours ADD CONSTRAINT CompositionCours_PK PRIMARY KEY ( idParcours, idCours ) ;


ALTER TABLE Assiste ADD CONSTRAINT Assiste_Groupe_FK FOREIGN KEY ( idGroupe ) REFERENCES Groupe ( idGroupe ) ON
DELETE CASCADE NOT DEFERRABLE ;

ALTER TABLE Assiste ADD CONSTRAINT Assiste_Seance_FK FOREIGN KEY ( idSeance ) REFERENCES Seance ( idSeance ) NOT DEFERRABLE ;

ALTER TABLE Seance ADD CONSTRAINT fk_Cours_Enseignant1 FOREIGN KEY ( idEnseignant ) REFERENCES Enseignant ( idEnseignant ) NOT DEFERRABLE ;

ALTER TABLE Seance ADD CONSTRAINT fk_Cours_Enseignement1 FOREIGN KEY ( idCours ) REFERENCES Cours ( idCours ) NOT DEFERRABLE ;

ALTER TABLE Seance ADD CONSTRAINT fk_Cours_Salle1 FOREIGN KEY ( idSalle ) REFERENCES Salle ( idSalle ) NOT DEFERRABLE ;

ALTER TABLE Cours ADD CONSTRAINT fk_Enseignement_Enseignant1 FOREIGN KEY ( Responsable ) REFERENCES Enseignant ( idEnseignant ) NOT DEFERRABLE ;

ALTER TABLE Inscription ADD CONSTRAINT fk_Inscription_Etudiant1 FOREIGN KEY ( idEtudiant ) REFERENCES Etudiant ( idEtudiant ) NOT DEFERRABLE ;

ALTER TABLE Inscription ADD CONSTRAINT fk_Inscription_Parcours1 FOREIGN KEY ( idParcours ) REFERENCES Parcours ( idParcours ) NOT DEFERRABLE ;

ALTER TABLE Passage ADD CONSTRAINT fk_Passage_Parcours1 FOREIGN KEY ( idParcours ) REFERENCES Parcours ( idParcours ) NOT DEFERRABLE ;

ALTER TABLE Passage ADD CONSTRAINT fk_Passage_Parcours2 FOREIGN KEY ( idParcoursSup ) REFERENCES Parcours ( idParcours ) NOT DEFERRABLE ;

ALTER TABLE Resultat ADD CONSTRAINT fk_Resultat_Cours FOREIGN KEY ( idCours ) REFERENCES Cours ( idCours ) ;
ALTER TABLE Resultat ADD CONSTRAINT fk_Resultat_Etudiant FOREIGN KEY ( idEtudiant ) REFERENCES Etudiant ( idEtudiant ) ;

ALTER TABLE Salle ADD CONSTRAINT fk_Salle_Batiment1 FOREIGN KEY ( idBatiment ) REFERENCES Batiment ( idBatiment ) NOT DEFERRABLE ;

ALTER TABLE Service ADD CONSTRAINT fk_Service_Enseignant FOREIGN KEY ( idEnseignant ) REFERENCES Enseignant ( idEnseignant ) NOT DEFERRABLE ;

ALTER TABLE CompositionCours ADD CONSTRAINT CompositionCours_Cours_FK FOREIGN KEY ( idCours ) REFERENCES Cours ( idCours ) ;
ALTER TABLE CompositionCours ADD CONSTRAINT CompositionCours_Parcours_FK FOREIGN KEY ( idParcours ) REFERENCES Parcours ( idParcours ) ;
